@@ -1,5 +1,5 @@
 
-# $Id: Completed.pm,v 1.31 2009/01/22 03:39:57 Martin Exp $
+# $Id: Completed.pm,v 1.34 2013-08-21 01:27:12 Martin Exp $
 
 =head1 NAME
 
@@ -48,16 +48,15 @@ use warnings;
 
 use Carp;
 use Date::Manip;
-# We need the version that was fixed to be able to parse completed
-# item search results:
-use WWW::Search::Ebay 2.217;
+# We need the version that was fixed to look for "Free Shipping":
+use WWW::Search::Ebay 2.247;
 use WWW::Ebay::Session;
 use base 'WWW::Search::Ebay';
 
 our
-$VERSION = do { my @r = (q$Revision: 1.31 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.34 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
-my $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
+our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 use constant DEBUG_FUNC => 0;
 
@@ -96,7 +95,8 @@ sub login
   my ($sUserID, $sPassword) = @_;
   if (ref $self->{__ebay__session__})
     {
-    DEBUG_FUNC && print STDERR " +   login() was already called.\n";
+    use Data::Dumper;
+    DEBUG_FUNC && print STDERR " +   login() was already called, I have these cookies:", Dumper($self->{__ebay__session__}->cookie_jar);
     return 1;
     } # if
   DEBUG_FUNC && print STDERR " + Ebay::Completed::login($sUserID)\n";
@@ -146,21 +146,13 @@ sub _preprocess_results_page
   exit 88;
   } # preprocess_results_page
 
-sub _columns
+sub _columns_USE_SUPER
   {
   my $self = shift;
   # This is for basic USA eBay:
-  return qw( paypal bids price shipping enddate );
+  return qw( paypal bids price enddate );
   } # _columns
 
-sub _title_element_specs
-  {
-  return (
-          '_tag' => 'td',
-          'class' => 'ebUpper ebcTtl',
-         );
-  } # _title_element_specs
-
 
 =head2 _parse_enddate
 
@@ -180,12 +172,15 @@ sub _parse_enddate
     }
   my $s = $oTDdate->as_text;
   print STDERR " DDD   TDdate ===$s===\n" if 1 < $self->{_debug};
+  $s =~ s/END\sDATE://i;
+  # Thanks to Jay for this fix:
+  $s =~ s/TIME\s*LEFT://i;
   # I don't know why there are sometimes weird characters in there:
   $s =~ s!&Acirc;!!g;
   $s =~ s!!!g;
   # Convert nbsp to regular space:
   $s =~ s!\240!\040!g;
-  my $date = &ParseDate($s);
+  my $date = ParseDate($s);
   print STDERR " DDD     date ===$date===\n" if 1 < $self->{_debug};
   my $sDate = $self->_format_date($date);
   $hit->end_date($sDate);
@@ -219,18 +214,3 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 =cut
 
 __END__
-
-This is the HTML for one result, as of 2006-02-18:
-
-<tr class="ebHlOdd ebUpper">
-<td rowspan="2" class="ebLeft"></td>
-<td class="ebcPic" rowspan="2"><a href="http://cgi.ebay.com/Star-Wars-POTJ-Shmi-Skywalker-MOC_W0QQitemZ6036472221QQcategoryZ50269QQrdZ1QQcmdZViewIte"m><img height="20" width="20" border="0" title="Listing has pictures" alt="Listing has pictures" src="http://pics.ebaystatic.com/aw/pics/icon/iconPic_20x20.gif"></img></a></td>
-<td class="ebUpper ebcTtl" colspan="5"><h3 class="ens fontnormal"><a href="http://cgi.ebay.com/Star-Wars-POTJ-Shmi-Skywalker-MOC_W0QQitemZ6036472221QQcategoryZ50269QQrdZ1QQcmdZViewItem">Star Wars POTJ - Shmi Skywalker - MOC!!</a></h3><span class="icons"><img border="0" src="http://pics.ebaystatic.com/aw/pics/s.gif" id="sr_giftIcon_0"></img></span></td>
-<td class="ebcAct" rowspan="2"><ul class="navigation"><li><span><a href="http://search.ebay.com/search/search.dll?GetResult&amp;query=Star+Wars+POTJ++-++Shmi+Skywalker++-++MOC%21%21&amp;sibeleafcat=50269&amp;sim=y">View similar active items</a></span></li><li><span><a href="http://cgi5.ebay.com/ws2/eBayISAPI.dll?SellLikeItem&amp;Item=6036472221">List an item like this</a></span></li></ul></td>
-<td rowspan="2" class="ebRight"></td></tr>
-<tr class="ebHlOdd ebLower">
-<td class="ebLower"></td>
-<td class="ebLower ebcBid">1</td>
-<td class="ebLower ebcPr"><span class="ebSold">$0.99</span><br /></td>
-<td class="ebLower ebcShpNew"><span class="shpTxt">$4.00</span></td>
-<td class="ebLower ebcTim">Feb-1721:23</td></tr>
